Welcome to DataProcessor's documentation!
=========================================

DataProcessor is a package that processes the data collected from BicycleDAQ_.

.. _BicycleDAQ: http://github.com/moorepants/BicycleDAQ

Contents:

.. toctree::
   :maxdepth: 2

   installation.rst
   bicycledataprocessor.rst


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
